//
//  Util.m
//  TApp2
//
//  Created by iam on 04/04/17.
//  Copyright (c) 2017 Microfocus. All rights reserved.
//

#import "Util.h"

@implementation Util

NSString *const configFilename = @"Account.cfg";

+ (void) saveConfig:(AccountConfig *)cfg
{
    NSString *filename = [self pathForMetadataFile:[self buildFilename:cfg]];
    NSLog(@"Saved AccountConfig - %@ to file %@", ([NSKeyedArchiver archiveRootObject:cfg toFile:filename]) ? @"YES" : @"NO", filename);
}

+ (void) deleteConfig:(AccountConfig *)cfg
{
    NSError *error;
    NSString *filename = [self pathForMetadataFile:[self buildFilename:cfg]];
    [[NSFileManager defaultManager] removeItemAtPath:filename error:&error];
    NSLog(@"Deleted AccountConfig - %@ file %@", (error == nil) ? @"YES" : @"NO", filename);
}

+ (AccountConfig *) getAccountConfigFor:(NSString *) acctName in:(NSArray *) arConfig
{
    for (AccountConfig *cfg in arConfig) {
        if ([cfg.getAccountName isEqualToString:acctName])
            return cfg;
    }
    return nil;
}

+ (NSMutableArray *) loadConfigs
{
    NSMutableArray *arConfigs = [[NSMutableArray alloc] init];
    NSArray * arFilenames = [self getAllAccountConfigFilenamesAt:[NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) objectAtIndex:0]];
    for (NSString *filename in arFilenames) {
        if ([filename hasSuffix:configFilename]) {
            [arConfigs addObject:[self loadConfig:filename]];
        }
    }
    return arConfigs;
}

+ (AccountConfig *) loadConfig:(NSString *)filename
{
    AccountConfig *cfg = (AccountConfig *) [NSKeyedUnarchiver unarchiveObjectWithFile:[self pathForMetadataFile:filename]];
    NSLog(@"filename:%@ - %@", filename, [cfg description]);
    return cfg;
}

+ (NSString *) pathForMetadataFile:(NSString *) fileName
{
    BOOL status = NO;
    NSFileManager *fileManager = [NSFileManager defaultManager];
    
    NSString *documentsPath = [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) objectAtIndex:0];
    NSString *filePath = [documentsPath stringByAppendingPathComponent:fileName];
    
    if ([fileManager fileExistsAtPath:documentsPath] == NO)
    {
        status = [fileManager createDirectoryAtPath:documentsPath withIntermediateDirectories:NO attributes:nil error:nil];
        NSLog(@"Error creating Config File Directory Path %@", documentsPath);
    }
    
    return filePath;
}

+ (NSArray *) getAllAccountConfigFilenamesAt:(NSString *) path
{
    NSArray *directoryContent = [[NSFileManager defaultManager] contentsOfDirectoryAtPath:path error:NULL];
    return directoryContent;
}

+ (NSString *) buildFilename:(AccountConfig *)cfg
{
    NSString *filename = [[[[cfg.getAccountName stringByAppendingString:@"_"] stringByAppendingString:[cfg getProviderDomain]] stringByAppendingString:@"_"] stringByAppendingString:configFilename];
    
    return filename;
}

@end
